``pyramid_exclog``
===================

A package which logs Pyramid application exception (error) information to a
standard Python logger.  This add-on is most useful when used in production
applications, because the logger can be configured to log to a file, to UNIX
syslog, to the Windows Event Log, or even to email.

See the documentation at
http://docs.pylonsproject.org/projects/pyramid_exclog/en/latest/ for more
information.

This package will only work with Pyramid 1.2a1 and better.
